pitchtools.DiatonicObject
=========================

.. abjad-lineage:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject

.. autoclass:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__repr__
   :noindex:
